import React from 'react';
import { mount } from 'enzyme';
import { dataQa } from '@percona/platform-core';
import { Email } from './Email';

describe('Email::', () => {
  it('Renders with props', () => {
    const root = mount(
      <Email
        settings={{
          username: 'test',
          from: 'from@mail.com',
          smarthost: 'host.com',
          hello: 'hello',
        }}
        updateSettings={() => {}}
      />
    );

    expect(root.find(dataQa('username-text-input')).prop('value')).toEqual('test');
  });

  it('Disables apply changes on initial values', () => {
    const root = mount(
      <Email
        settings={{
          username: 'test',
          from: 'from@mail.com',
          smarthost: 'host.com',
          hello: 'hello',
        }}
        updateSettings={() => {}}
      />
    );
    const button = root.find('button');

    expect(button.prop('disabled')).toBeTruthy();
  });

  it('Disables username and password when NONE is selected', () => {
    const root = mount(
      <Email
        settings={{
          from: 'from@mail.com',
          smarthost: 'host.com',
          hello: 'hello',
        }}
        updateSettings={() => {}}
      />
    );

    expect(root.find(dataQa('username-text-input')).prop('disabled')).toBeTruthy();
    expect(root.find(dataQa('password-password-input')).prop('disabled')).toBeTruthy();
  });

  it('Enabled username and password when NONE is not selected', () => {
    const root = mount(
      <Email
        settings={{
          username: 'user',
          password: 'pass',
          from: 'from@mail.com',
          smarthost: 'host.com',
          hello: 'hello',
        }}
        updateSettings={() => {}}
      />
    );

    expect(root.find(dataQa('username-text-input')).prop('disabled')).toBeFalsy();
    expect(root.find(dataQa('password-password-input')).prop('disabled')).toBeFalsy();
  });
});
